@@ -1,6 +1,6 @@
 (* Otags III
  * 
- * Hendrik Tews Copyright (C) 2010 - 2016
+ * Hendrik Tews Copyright (C) 2010 - 2017
  * 
  * This file is part of "Otags III".
  * 
@@ -40,21 +40,4 @@ let append_to_tags_file = ref false
 
 let relative_file_prefix = ref ""
 
-  (* Whether some "-external" occured. Then "-pr" and "-pc" do not 
-   * switch back to internal mode
-   *)
-let switched_to_external_by_hand = ref false
-
-let default_parser_list = [
-  "Camlp4OCamlRevisedParser";
-  "Camlp4OCamlParser";
-]
-
-
-let user_parser_list = ref default_parser_list
-
-let camlp4_search_path = ref []
-
 let exit_status = ref 0
-
-let parser_hints_list = ref []
