@@ -1,9 +1,6 @@
 
 let f1 x = 12
-(*
-type a =
-  | A of int  | B
-*)
+
 type a =
   | A of int
   | B  | C
@@ -58,9 +55,6 @@ end
 
 let f8 : int -> int = fun x -> x
 
-(* Bug pointed by Hendrik Tews *)
-(* Status: not fixed *)
-
 type a_type = 
   | A1 of b_type
   | A2 of a_type
