@@ -1,6 +1,6 @@
 (* Otags III
  * 
- * Hendrik Tews Copyright (C) 2010 - 2016
+ * Hendrik Tews Copyright (C) 2010 - 2017
  * 
  * This file is part of "Otags III".
  * 
@@ -26,6 +26,7 @@
 open Global
 open Otags_types
 open Source_channel
+open Fix_location
 
 
 type vi_tag = {
@@ -132,7 +133,8 @@ let start_unit vs file =
   add_tag vs {tag = mod_name; tag_file = file; address = "1"; position = 0}
 
 
-let write_tag vs loc tag = 
+let write_tag vs loc tag =
+  let loc = fix_loc loc in
   let loc_line =
     (* if loc is wrong (eg, because of line directives), input_line
      * will throw End_of_file.
